OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "Favoritos",
    "Shared with you" : "Compartite con te",
    "Tags" : "Etiquettas",
    "Back" : "Retro",
    "Save" : "Salveguardar",
    "Shared by" : "Compartite per",
    "Favorite" : "Favorite",
    "Go back" : "Retornar",
    "Home" : "Initio",
    "General" : "General",
    "Remove from favorites" : "Remove from favorites",
    "Details" : "Detalios",
    "Cancel" : "Cancel",
    "Confirm" : "Confirmar",
    "Group" : "Gruppo",
    "View" : "Vider",
    "Add" : "Adder"
},
"nplurals=2; plural=(n != 1);");
